aboutsummaryrefslogtreecommitdiff
path: root/examples/usart
diff options
context:
space:
mode:
Diffstat (limited to 'examples/usart')
-rw-r--r--examples/usart/usart.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/usart/usart.c b/examples/usart/usart.c
index 72dbd75..db43372 100644
--- a/examples/usart/usart.c
+++ b/examples/usart/usart.c
@@ -42,13 +42,13 @@ void clock_setup(void)
void usart_setup(void)
{
/* Enable clocks for GPIO port B (for GPIO_USART_TX) and USART3. */
rcc_enable_peripheral_clock(&RCC_APB2ENR, IOPBEN);
rcc_enable_peripheral_clock(&RCC_APB1ENR, USART3EN);
/* Setup GPIO pin GPIO_USART_TX/GPIO10 on GPIO port B for transmit. */
gpio_set_mode(GPIOB, GPIO_MODE_OUTPUT_50_MHZ,
- GPIO_CNF_OUTPUT_ALTFN_PUSHPULL, GPIO_USART_TX);
+ GPIO_CNF_OUTPUT_ALTFN_PUSHPULL, GPIO_USART3_TX);
/* Setup UART parameters. */
usart_set_baudrate(USART3, 38400);
@@ -42,13 +42,13 @@ void clock_setup(void)
void usart_setup(void)
{
- /* Enable clocks for GPIO port B (for GPIO_USART_TX) and USART3. */
+ /* Enable clocks for GPIO port B (for GPIO_USART3_TX) and USART3. */
rcc_enable_peripheral_clock(&RCC_APB2ENR, IOPBEN);
rcc_enable_peripheral_clock(&RCC_APB1ENR, USART3EN);
@@ -42,13 +42,13 @@ void clock_setup(void)
rcc_enable_peripheral_clock(&RCC_APB2ENR, IOPBEN);
rcc_enable_peripheral_clock(&RCC_APB1ENR, USART3EN);
- /* Setup GPIO pin GPIO_USART_TX/GPIO10 on GPIO port B for transmit. */
+ /* Setup GPIO pin GPIO_USART3_TX/GPIO10 on GPIO port B for transmit. */
gpio_set_mode(GPIOB, GPIO_MODE_OUTPUT_50_MHZ,